@@ -3,9 +3,9 @@ package com.sun.tools.jdeps.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "22" },
-            { "jdk", "22" },
-            { "release", "22" },
+            { "full", "23.0.2" },
+            { "jdk", "23.0.2" },
+            { "release", "23.0.2" },
         };
     }
 }
