@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -98,11 +98,16 @@ public class FormatData_ar_MR extends ListResourceBundle {
         };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
-            { "japanese.MonthNames", metaValue_MonthNames },
-            { "roc.MonthAbbreviations", metaValue_MonthNames },
-            { "buddhist.MonthAbbreviations", metaValue_MonthNames },
+            { "standalone.MonthNames", metaValue_MonthNames },
             { "MonthAbbreviations", metaValue_MonthNames },
+            { "standalone.MonthAbbreviations", metaValue_MonthNames },
+            { "MonthNarrows", metaValue_MonthNarrows },
+            { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.MonthNames", metaValue_MonthNames },
+            { "japanese.MonthNames", metaValue_MonthNames },
+            { "japanese.MonthAbbreviations", metaValue_MonthNames },
+            { "roc.MonthNames", metaValue_MonthNames },
+            { "roc.MonthAbbreviations", metaValue_MonthNames },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -120,23 +125,14 @@ public class FormatData_ar_MR extends ListResourceBundle {
                     "",
                 }
             },
-            { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.MonthAbbreviations", metaValue_MonthNames },
-            { "roc.MonthNames", metaValue_MonthNames },
-            { "standalone.MonthNames", metaValue_MonthNames },
-            { "standalone.MonthAbbreviations", metaValue_MonthNames },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
-                    "\u00a4\u00a0#,##0.00",
+                    "\u200f#,##0.00\u00a0\u00a4;\u200f-#,##0.00\u00a0\u00a4",
                     "#,##0%",
-                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                    "\u061c#,##0.00\u00a4;(\u061c#,##0.00\u00a4)",
                 }
             },
-            { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
         };
         return data;
     }
