@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -68,10 +68,8 @@ public class LocaleNames_eu extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final String metaValue_ban = "baliera";
         final String metaValue_bug = "buginera";
-        final String metaValue_chr = "txerokiera";
         final String metaValue_si = "sinhala";
         final String metaValue_tl = "tagaloa";
-        final String metaValue_vai = "vaiera";
         final Object[][] data = new Object[][] {
             { "001", "Mundua" },
             { "002", "Afrika" },
@@ -403,7 +401,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "el", "greziera" },
             { "en", "ingelesa" },
             { "eo", "esperantoa" },
-            { "es", "espainiera" },
+            { "es", "gaztelania" },
             { "et", "estoniera" },
             { "eu", "euskara" },
             { "fa", "persiera" },
@@ -412,7 +410,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "fj", "fijiera" },
             { "fo", "faroera" },
             { "fr", "frantsesa" },
-            { "fy", "frisiera" },
+            { "fy", "mendebaldeko frisiera" },
             { "ga", "irlandera" },
             { "gd", "Eskoziako gaelikoa" },
             { "gl", "galiziera" },
@@ -480,7 +478,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "nl", "nederlandera" },
             { "nn", "nynorsk (norvegiera)" },
             { "no", "norvegiera" },
-            { "nr", "hegoaldeko ndebelera" },
+            { "nr", "hegoaldeko ndebeleera" },
             { "nv", "navajoera" },
             { "ny", "chewera" },
             { "oc", "okzitaniera" },
@@ -537,7 +535,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "ve", "vendera" },
             { "vi", "vietnamera" },
             { "vo", "volap\u00fck" },
-            { "wa", "waloiera" },
+            { "wa", "valoniera" },
             { "wo", "wolofera" },
             { "xh", "xhosera" },
             { "yi", "yiddisha" },
@@ -565,6 +563,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "bas", "basaa" },
             { "bem", "bembera" },
             { "bez", "benera" },
+            { "bgc", "haryanera" },
             { "bho", "bhojpurera" },
             { "bin", "edoera" },
             { "bla", "siksikera" },
@@ -579,8 +578,8 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "chm", "mariera" },
             { "cho", "txoktawera" },
             { "chp", "chipewyera" },
-            { "chr", metaValue_chr },
-            { "chy", "txeienera" },
+            { "chr", "txerokiera" },
+            { "chy", "txeieneera" },
             { "ckb", "erdialdeko kurduera" },
             { "clc", "chilcotinera" },
             { "crg", "metisera" },
@@ -725,6 +724,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "pqm", "maliseet-passamaquoddyera" },
             { "prg", "prusiera" },
             { "quc", "quicheera" },
+            { "raj", "rajastanera" },
             { "rap", "rapanuia" },
             { "rar", "rarotongera" },
             { "rhg", "rohingyera" },
@@ -748,25 +748,25 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "smj", "Luleko samiera" },
             { "smn", "Inariko samiera" },
             { "sms", "skolten samiera" },
-            { "snk", "soninkera" },
-            { "srn", "srananera" },
+            { "snk", "soninkeera" },
+            { "srn", "sranan tongoa" },
             { "ssy", "sahoa" },
             { "str", "itsasarteetako salishera" },
             { "suk", "sukumera" },
             { "swb", "komoreera" },
             { "syr", "asiriera" },
             { "tce", "hegoaldeko tutchoneera" },
-            { "tem", "temnea" },
+            { "tem", "temneera" },
             { "teo", "tesoera" },
             { "tet", "tetuma" },
             { "tgx", "tagishera" },
             { "tht", "tahltanera" },
-            { "tig", "tigrea" },
+            { "tig", "tigreera" },
             { "tlh", "klingonera" },
             { "tli", "tlingitera" },
             { "tok", "toki pona" },
             { "tpi", "tok pisin" },
-            { "trv", "tarokoa" },
+            { "trv", "tarokoera" },
             { "ttm", "iparraldeko tutchoneera" },
             { "tum", "tumbukera" },
             { "tvl", "tuvaluera" },
@@ -776,12 +776,12 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "udm", "udmurtera" },
             { "umb", "umbundua" },
             { "und", "hizkuntza ezezaguna" },
-            { "vai", metaValue_vai },
+            { "vai", "vaiera" },
             { "vec", "veneziera" },
             { "vun", "vunjoa" },
             { "wae", "walserera" },
-            { "wal", "welayta" },
-            { "war", "samerera" },
+            { "wal", "wolayttera" },
+            { "war", "warayera" },
             { "wuu", "wu txinera" },
             { "xal", "kalmykera" },
             { "xog", "sogera" },
@@ -790,14 +790,14 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "yrl", "nheengatua" },
             { "yue", "kantonera" },
             { "zgh", "amazigera estandarra" },
-            { "zun", "zu\u00f1ia" },
+            { "zun", "zu\u00f1iera" },
             { "zxx", "ez dago eduki linguistikorik" },
             { "zza", "zazera" },
-            { "Adlm", "adlam" },
+            { "Adlm", "adlama" },
             { "Aghb", "Kaukasoko albaniera" },
             { "Ahom", "ahomera" },
             { "Arab", "arabiarra" },
-            { "Aran", "nastaliq" },
+            { "Aran", "nastaliqa" },
             { "Armi", "aramiera inperiarra" },
             { "Armn", "armeniarra" },
             { "Avst", "avestera" },
@@ -816,7 +816,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "Cans", "Kanadiako aborigenen silabiko bateratua" },
             { "Cari", "kariera" },
             { "Cham", "txamera" },
-            { "Cher", metaValue_chr },
+            { "Cher", "txerokiarra" },
             { "Chrs", "korasmiera" },
             { "Copt", "koptikera" },
             { "Cpmn", "zipro-minoera" },
@@ -840,7 +840,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "Grek", "grekoa" },
             { "Gujr", "gujaratarra" },
             { "Guru", "gurmukhia" },
-            { "Hanb", "h\u00e4nera" },
+            { "Hanb", "idazkera txinatarra bopomofoarekin" },
             { "Hang", "hangula" },
             { "Hani", "idazkera txinatarra" },
             { "Hano", "hanunuera" },
@@ -891,7 +891,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "Modi", "modiera" },
             { "Mong", "mongoliarra" },
             { "Mroo", "mroera" },
-            { "Mtei", "meitei mayekera" },
+            { "Mtei", "meiteiarra" },
             { "Mult", "multaniera" },
             { "Mymr", "birmaniarra" },
             { "Nagm", "nag mundariera" },
@@ -899,10 +899,10 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "Narb", "iparraldeko arabiera zaharra" },
             { "Nbat", "nabatera" },
             { "Newa", "newaera" },
-            { "Nkoo", "n\u2019ko" },
+            { "Nkoo", "n\u2019koa" },
             { "Nshu", "nushuera" },
             { "Ogam", "oghamera" },
-            { "Olck", "ol txikiera" },
+            { "Olck", "ol chikia" },
             { "Orkh", "orkhonera" },
             { "Orya", "oriyarra" },
             { "Osge", "osagera" },
@@ -919,7 +919,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "Prti", "Partiera inskripzioak" },
             { "Qaag", "zauagiera" },
             { "Rjng", "Rejang" },
-            { "Rohg", "hanifiera" },
+            { "Rohg", "hanifia" },
             { "Runr", "errunikoa" },
             { "Samr", "samariera" },
             { "Sarb", "hegoaldeko arabiera zaharra" },
@@ -934,9 +934,9 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "Sogo", "sogdiera zaharra" },
             { "Sora", "sora sompeng" },
             { "Soyo", "soyomboera" },
-            { "Sund", "sudanera" },
+            { "Sund", "sudandarra" },
             { "Sylo", "syloti nagriera" },
-            { "Syrc", "siriera" },
+            { "Syrc", "asiriarra" },
             { "Tagb", "tagbanwa" },
             { "Takr", "takriera" },
             { "Tale", "tai le" },
@@ -945,7 +945,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "Tang", "tangutera" },
             { "Tavt", "tai viet" },
             { "Telu", "teluguarra" },
-            { "Tfng", "tifinagera" },
+            { "Tfng", "tifinagha" },
             { "Tglg", metaValue_tl },
             { "Thaa", "thaana" },
             { "Thai", "thailandiarra" },
@@ -954,18 +954,18 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "Tnsa", "tangsa" },
             { "Toto", "totoera" },
             { "Ugar", "ugaritiera" },
-            { "Vaii", metaValue_vai },
+            { "Vaii", "vaiarra" },
             { "Vith", "vithkuqi" },
             { "Wara", "varang kshiti" },
             { "Wcho", "wanchoera" },
             { "Xpeo", "pertsiera zaharra" },
             { "Xsux", "sumero-akadiera kuneiformea" },
             { "Yezi", "yezidiera" },
-            { "Yiii", "yiera" },
+            { "Yiii", "yiarra" },
             { "Zanb", "zanabazar koadroa" },
             { "Zinh", "heredatua" },
             { "Zmth", "matematikako notazioa" },
-            { "Zsye", "emotikonoa" },
+            { "Zsye", "emojiak" },
             { "Zsym", "ikurrak" },
             { "Zxxx", "idatzi gabea" },
             { "Zyyy", "ohikoa" },
@@ -976,8 +976,8 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "en_CA", "Kanadako ingelesa" },
             { "en_GB", "Britainia Handiko ingelesa" },
             { "en_US", "ingeles amerikarra" },
-            { "es_ES", "espainiera (Europa)" },
-            { "es_MX", "Mexikoko espainiera" },
+            { "es_ES", "Europako gaztelania" },
+            { "es_MX", "Mexikoko gaztelania" },
             { "fa_AF", "daria" },
             { "fr_CA", "Kanadako frantsesa" },
             { "fr_CH", "Suitzako frantsesa" },
@@ -990,7 +990,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "%%1994", "Resiako ortografia estandarizatua" },
             { "%%1996", "1996ko ortografia alemana" },
             { "ar_001", "arabiera moderno estandarra" },
-            { "es_419", "Latinoamerikako espainiera" },
+            { "es_419", "Latinoamerikako gaztelania" },
             { "key.ca", "Egutegia" },
             { "key.cf", "Moneta-formatua" },
             { "key.co", "Ordenatzeko irizpidea" },
@@ -1026,6 +1026,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "%%SOLBA", "Stolvizza/Solbica dialektoa" },
             { "%%SOTAV", "Caboverdeerako sotavento dialekto taldea" },
             { "%%UCCOR", "Ortografia bateratua" },
+            { "hi_Latn", "hindia (latindarra)" },
             { "zh_Hans", "txinera sinplifikatua" },
             { "zh_Hant", "txinera tradizionala" },
             { "%%AO1990", "1990eko portugesaren ortografia-hitzarmena" },
@@ -1201,7 +1202,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "type.ms.metric", "Sistema metrikoa" },
             { "type.nu.native", "Zenbaki-sistema" },
             { "type.ca.chinese", "Txinatar egutegia" },
-            { "type.ca.islamic", "Islamiar egutegia" },
+            { "type.ca.islamic", "Egutegi islamiarra" },
             { "type.ca.iso8601", "ISO-8601 egutegia" },
             { "type.ca.persian", "Egutegi persiarra" },
             { "type.cf.account", "Kontabilitateko moneta-formatua" },
@@ -1222,7 +1223,6 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "type.ca.japanese", "Japoniar egutegia" },
             { "type.cf.standard", "Moneta-formatu estandarra" },
             { "type.co.phonetic", "Ordenatzeko irizpide fonetikoa" },
-            { "type.co.reformed", "Erreformaren araberako hurrenkera" },
             { "type.co.searchjl", "Bilatu hangularen lehen kontsonantearen arabera" },
             { "type.co.standard", "Ordenatzeko irizpide estandarra" },
             { "type.ms.uksystem", "Neurketa-sistema inperiala" },
@@ -1242,10 +1242,8 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "type.co.dictionary", "Hurrenkera alfabetikoa" },
             { "type.co.traditional", "Tradizionala" },
             { "type.nu.traditional", "Zenbaki tradizionalak" },
-            { "type.ca.islamic-rgsa", "Islamiar egutegia (Saudi Arabia, ikuspegiak)" },
-            { "type.ca.islamic-tbla", "Islamiar egutegia (taula-formakoa, gai astronomikokoa)" },
-            { "type.ca.islamic-civil", "Islamiar egutegia (taula-formakoa, garai zibilekoa)" },
-            { "type.ca.islamic-umalqura", "Islamiar egutegia (Umm al-Qura)" },
+            { "type.ca.islamic-civil", "Egutegi islamiarra (taula-formakoa, garai zibilekoa)" },
+            { "type.ca.islamic-umalqura", "Egutegi islamiarra (Umm al-Qura)" },
             { "type.ca.ethiopic-amete-alem", "Amete Alem egutegi etiopiarra" },
         };
         return data;
