@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -66,6 +66,7 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_tk extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_chr = "\u00e7eroki";
         final Object[][] data = new Object[][] {
             { "001", "D\u00fcn\u00fd\u00e4" },
             { "002", "Afrika" },
@@ -471,6 +472,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ng", "ndonga dili" },
             { "nl", "niderland dili" },
             { "nn", "norwegi\u00fda n\u00fdunorsk dili" },
+            { "no", "norweg dili" },
             { "nr", "g\u00fcnorta ndebele dili" },
             { "nv", "nawaho dili" },
             { "ny", "n\u00fdanja dili" },
@@ -539,37 +541,52 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ain", "a\u00fdn dili" },
             { "ale", "aleut dili" },
             { "alt", "g\u00fcnorta Alta\u00fd dili" },
+            { "ann", "obolo dili" },
             { "anp", "angika dili" },
             { "arn", "mapu\u00e7e dili" },
             { "arp", "arapaho dili" },
+            { "ars", "nejdi arap dili" },
             { "asa", "asu dili" },
             { "ast", "asturi\u00fd dili" },
+            { "atj", "atikamekw dili" },
             { "awa", "awadhi dili" },
             { "ban", "bali\u00fd dili" },
             { "bas", "basaa dili" },
             { "bem", "bemba dili" },
             { "bez", "bena dili" },
+            { "bgc", "har\u00fdanwi dili" },
             { "bho", "bhojpuri dili" },
             { "bin", "bini dili" },
             { "bla", "siksika dili" },
             { "brx", "bodo dili" },
             { "bug", "bugi\u00fd dili" },
             { "byn", "blin dili" },
+            { "cay", "ka\u00fduga dili" },
             { "ccp", "\u00e7akma dili" },
             { "ceb", "sebuan dili" },
             { "cgg", "kiga" },
             { "chk", "\u00e7uuk dili" },
             { "chm", "mari\u00fd dili" },
             { "cho", "\u00e7okto" },
-            { "chr", "\u00e7eroki" },
+            { "chp", "\u00e7ipew\u00fdan dili" },
+            { "chr", metaValue_chr },
             { "chy", "\u015fa\u00fdenn dili" },
             { "ckb", "merkezi k\u00fcrt dili" },
+            { "clc", "\u00e7ilkotin dili" },
+            { "crg", "mi\u00e7if dili" },
+            { "crj", "g\u00fcnorta-g\u00fcndogar kri dili" },
+            { "crk", "d\u00fczde\u00e7i kri dili" },
+            { "crl", "demirgazyk-g\u00fcndogar kri dili" },
+            { "crm", "los-kri dili" },
+            { "crr", "karolina algonkin dili" },
             { "crs", "seselwa kreole-fransuz dili" },
+            { "csw", "batgalyk kri dili" },
             { "dak", "dakota dili" },
             { "dar", "dargi dili" },
             { "dav", "taita dili" },
             { "dgr", "dogrib dili" },
             { "dje", "zarma dili" },
+            { "doi", "Dogri" },
             { "dsb", "a\u015faky lu\u017eits dili" },
             { "dua", "duala dili" },
             { "dyo", "\u00fdola-fon\u00fdi dili" },
@@ -580,6 +597,8 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ewo", "ewondo dili" },
             { "fil", "filippin dili" },
             { "fon", "fon dili" },
+            { "frc", "fransuz dilini\u0148 kajun \u015fiwesi" },
+            { "frr", "demirgazyk friz dili" },
             { "fur", "friul dili" },
             { "gaa", "ga dili" },
             { "gez", "geez dili" },
@@ -588,13 +607,17 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "gsw", "nemes dili (\u015ewe\u00fdsari\u00fda)" },
             { "guz", "gusii dili" },
             { "gwi", "gwi\u00e7in dili" },
+            { "hai", "ha\u00fdda dili" },
             { "haw", "gawa\u00fd dili" },
+            { "hax", "g\u00fcnorta ha\u00fdda dili" },
             { "hil", "hiliga\u00fdnon dili" },
             { "hmn", "hmong dili" },
             { "hsb", "\u00fdokarky lu\u017eits dili" },
             { "hup", "hupa" },
+            { "hur", "halkomelem dili" },
             { "iba", "iban dili" },
             { "ibb", "ibibio dili" },
+            { "ikt", "G\u00fcnorta Kanada iniktitut dili" },
             { "ilo", "iloko dili" },
             { "inh", "ingu\u015f dili" },
             { "jbo", "lojban dili" },
@@ -609,6 +632,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "kde", "makonde dili" },
             { "kea", "kabuwerdianu dili" },
             { "kfo", "koro dili" },
+            { "kgp", "ka\u00fdngang dili" },
             { "kha", "khasi dili" },
             { "khq", "ko\u00fdra-\u00e7ini dili" },
             { "kkj", "kako dili" },
@@ -623,12 +647,16 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ksf", "bafia dili" },
             { "ksh", "keln dili" },
             { "kum", "kumyk dili" },
+            { "kwk", "kwakwala dili" },
             { "lad", "ladino dili" },
             { "lag", "langi dili" },
             { "lez", "lezgin dili" },
+            { "lil", "lilluet dili" },
             { "lkt", "lakota dili" },
+            { "lou", "Luiziana kreol dili" },
             { "loz", "lozi dili" },
             { "lrc", "demirgazyk luri dili" },
+            { "lsm", "sami\u00fda dili" },
             { "lua", "luba-Lulua dili" },
             { "lun", "lunda dili" },
             { "luo", "luo dili" },
@@ -648,6 +676,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "mic", "mikmak dili" },
             { "min", "minangkabau dili" },
             { "mni", "manipuri dili" },
+            { "moe", "innu-a\u00fdmun dili" },
             { "moh", "mogauk dili" },
             { "mos", "mossi dili" },
             { "mua", "mundang dili" },
@@ -669,15 +698,24 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "nso", "demirgazyk soto dili" },
             { "nus", "nuer dili" },
             { "nyn", "n\u00fdankole dili" },
+            { "ojb", "demirgazyk-g\u00fcnbatar ojibwa dili" },
+            { "ojc", "merkezi ojibwa dili" },
+            { "ojs", "oji-kri dili" },
+            { "ojw", "g\u00fcnbatar ojibwa dili" },
+            { "oka", "okanagan dili" },
             { "pag", "pangansinan dili" },
             { "pam", "kapampangan dili" },
             { "pap", "pap\u00fdamento dili" },
             { "pau", "palau dili" },
             { "pcm", "nigeri\u00fda-pijin dili" },
+            { "pis", "pijin dili" },
+            { "pqm", "malisit-passamakwodi dili" },
             { "prg", "prussi\u00fda dili" },
             { "quc", "ki\u00e7e dili" },
+            { "raj", "rajastani dili" },
             { "rap", "rapanu\u00fd dili" },
             { "rar", "kuk dili" },
+            { "rhg", "rohin\u00fda dili" },
             { "rof", "rombo dili" },
             { "rup", "arumyn dili" },
             { "rwk", "rwa dili" },
@@ -693,6 +731,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ses", "ko\u00fdraboro-senni dili" },
             { "shi", "tahelhit dili" },
             { "shn", "\u015fan dili" },
+            { "slh", "g\u00fcnorta Lu\u015futsid dili" },
             { "sma", "g\u00fcnorta saam dili" },
             { "smj", "lule-saam dili" },
             { "smn", "inari-saam dili" },
@@ -700,16 +739,23 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "snk", "soninke dili" },
             { "srn", "sranan-tongo dili" },
             { "ssy", "saho dili" },
+            { "str", "demirgazyk bogaz sali\u015f dili" },
             { "suk", "sukuma dili" },
             { "swb", "komor dili" },
             { "syr", "siri\u00fda dili" },
+            { "tce", "g\u00fcnorta tut\u00e7one dili" },
             { "tem", "temne dili" },
             { "teo", "teso dili" },
             { "tet", "tetum dili" },
+            { "tgx", "tagi\u015f dili" },
+            { "tht", "taltan dili" },
             { "tig", "tigre dili" },
             { "tlh", "klingon dili" },
+            { "tli", "tlinkit dili" },
+            { "tok", "toki pona dili" },
             { "tpi", "tok-pisin dili" },
             { "trv", "taroko dili" },
+            { "ttm", "demirgazyk tut\u00e7one dili" },
             { "tum", "tumbuka dili" },
             { "tvl", "tuwalu dili" },
             { "twq", "tasawak dili" },
@@ -723,20 +769,27 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "wae", "walzer dili" },
             { "wal", "wola\u00fdta dili" },
             { "war", "wara\u00fd dili" },
+            { "wuu", "u hyta\u00fd dili" },
             { "xal", "galmyk dili" },
             { "xog", "soga dili" },
             { "yav", "\u00fdangben dili" },
             { "ybb", "\u00fdemba dili" },
+            { "yrl", "nhengatu dili" },
             { "yue", "kanton dili" },
             { "zgh", "standart Marokko tamazight dili" },
             { "zun", "zuni dili" },
             { "zxx", "dil\u00e7ilige degi\u015fli mazmun \u00fdok" },
             { "zza", "zazaki dili" },
+            { "Adlm", "adlam" },
             { "Arab", "Arap elipbi\u00fdi" },
+            { "Aran", "Nastalik \u00fdazuwy" },
             { "Armn", "Ermeni elipbi\u00fdi" },
             { "Beng", "Bengal elipbi\u00fdi" },
             { "Bopo", "Bopomofo elipbi\u00fdi" },
             { "Brai", "Bra\u00fdl elipbi\u00fdi" },
+            { "Cakm", "\u00e7akma" },
+            { "Cans", "Kanadany\u0148 \u00fderlilerini\u0148 bogunlaryny\u0148 bitewile\u015fdirilen ulgamy" },
+            { "Cher", metaValue_chr },
             { "Cyrl", "Kiril elipbi\u00fdi" },
             { "Deva", "Dewanagari elipbi\u00fdi" },
             { "Ethi", "Efiop elipbi\u00fdi" },
@@ -762,14 +815,23 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "Latn", "Latyn elipbi\u00fdi" },
             { "Mlym", "Mala\u00fdalam elipbi\u00fdi" },
             { "Mong", "Mongol elipbi\u00fdi" },
+            { "Mtei", "me\u00fdte\u00fd-ma\u00fdek" },
             { "Mymr", "M\u00fdanma elipbi\u00fdi" },
+            { "Nkoo", "nko" },
+            { "Olck", "ol-\u00e7iki" },
             { "Orya", "Ori\u00fda elipbi\u00fdi" },
+            { "Rohg", "hanifi" },
             { "Sinh", "Singal elipbi\u00fdi" },
+            { "Sund", "Sundanez \u00fdazuwy" },
+            { "Syrc", "Siri\u00fda \u00fdazuwy" },
             { "Taml", "Tamil elipbi\u00fdi" },
             { "Telu", "Telugu elipbi\u00fdi" },
+            { "Tfng", "Tifinag \u00fdazuwy" },
             { "Thaa", "Taana elipbi\u00fdi" },
             { "Thai", "Ta\u00fd elipbi\u00fdi" },
             { "Tibt", "Tibet elipbi\u00fdi" },
+            { "Vaii", "Wa\u00fd \u00fdazuwy" },
+            { "Yiii", "\u00ddi \u00fdazuwy" },
             { "Zmth", "Matematiki belgiler" },
             { "Zsye", "Emoji" },
             { "Zsym", "Ny\u015fanlar" },
@@ -804,6 +866,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "type.nu.arab", "Arap-hindi sanlary" },
             { "type.nu.armn", "Ermeni sanlary" },
             { "type.nu.beng", "Bengal sanlary" },
+            { "type.nu.cakm", "\u00c7akma sanlary" },
             { "type.nu.deva", "Dewanagari sanlary" },
             { "type.nu.ethi", "Efiop sanlary" },
             { "type.nu.geor", "Gruzin sanlary" },
@@ -813,22 +876,27 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "type.nu.hans", "\u00dd\u00f6neke\u00fdle\u015fdirilen hyta\u00fd sanlary" },
             { "type.nu.hant", "Adaty hyta\u00fd sanlary" },
             { "type.nu.hebr", "\u00ddewre\u00fd sanlary" },
+            { "type.nu.java", "\u00ddawa sanlary" },
             { "type.nu.jpan", "\u00ddapon sanlary" },
             { "type.nu.khmr", "Khmer sanlary" },
             { "type.nu.knda", "Kannada sanlary" },
             { "type.nu.laoo", "Laos sanlary" },
             { "type.nu.latn", "Latyn sanlary" },
             { "type.nu.mlym", "Mala\u00fdalam sanlary" },
+            { "type.nu.mtei", "Mite\u00fd Ma\u00fdek sanlary" },
             { "type.nu.mymr", "M\u00fdanma sanlary" },
+            { "type.nu.olck", "Ol \u00c7iki sanlary" },
             { "type.nu.orya", "Ori\u00fda sanlary" },
             { "type.nu.taml", "Adaty tamil sanlary" },
             { "type.nu.telu", "Telugu sanlary" },
             { "type.nu.thai", "Ta\u00fd sanlary" },
             { "type.nu.tibt", "Tibet sanlary" },
+            { "type.nu.vaii", "Wa\u00fd sanlary" },
             { "type.ca.dangi", "Dangi senenamasy" },
             { "type.co.ducet", "Deslapky \u00ddunikod tertip rejesi" },
             { "type.lb.loose", "Setirden setire ge\u00e7i\u015fi\u0148 gow\u015fak stili" },
             { "type.nu.roman", "Rim sanlary" },
+            { "type.ca.coptic", "Kopt senenamasy" },
             { "type.ca.hebrew", "\u00ddewre\u00fd senenamasy" },
             { "type.co.search", "Umumy maksatly g\u00f6zleg" },
             { "type.lb.normal", "Setirden setire ge\u00e7i\u015fi\u0148 adaty stili" },
@@ -857,6 +925,10 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "type.nu.fullwide", "Doly gi\u0148likd\u00e4ki sanlar" },
             { "type.nu.romanlow", "Rim setir sanlary" },
             { "type.ca.gregorian", "Grigorian senenamasy" },
+            { "type.ca.islamic-tbla", "Hijri-kamary senenamasy (tablisaly, astronomik e\u00fd\u00fdam)" },
+            { "type.ca.islamic-civil", "Hijri-kamary senenamasy (tablisaly, ra\u00fdat e\u00fd\u00fdamy)" },
+            { "type.ca.islamic-umalqura", "Hijri-kamary senenamasy (Umm al-Kura)" },
+            { "type.ca.ethiopic-amete-alem", "Efiopi\u00fda Amete Alem senenamasy" },
         };
         return data;
     }
